@@ -1,8 +1,7 @@
-from . import models
-from . import movielens
-from . import callbacks
-from . import data
-from . import interface
-from . import losses
-from . import metrics
 from . import utils
+from . import data
+from . import maths
+from . import metrics
+from . import interface
+from . import callbacks
+from . import losses
